@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/glbox.cpp   3.0.5   edited Oct 12 2001 $
+** $Id: qt/glbox.cpp   3.2.1   edited May 13 09:08 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -60,6 +60,16 @@ void GLBox::paintGL()
     glLoadIdentity();
     transform();
     glCallList( object );
+    drawText();
+    qglColor( green );
+    glLineWidth( 1.0 );
+    glBegin( GL_LINES );
+    {
+	glVertex3f( 0.0, 0.0, 0.0 );
+	glVertex3f( 0.98, 0.98, 0.98 );
+    }
+    glEnd();
+    renderText( 1.0, 1.0, 1.0, "Wirebox", QFont( "helvetica", 12, QFont::Bold, TRUE ) );
 }
 
 
