@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/listviews.cpp   3.0.5   edited Feb 11 15:31 $
+** $Id: qt/listviews.cpp   3.2.1   edited May 13 09:08 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -144,7 +144,7 @@ ListViews::ListViews( QWidget *parent, const char *name )
 	     this, SLOT( slotMessageChanged() ) );
 
     messages->setSelectionMode( QListView::Extended );
-    // some preperationes
+    // some preparations
     folders->firstChild()->setOpen( TRUE );
     folders->firstChild()->firstChild()->setOpen( TRUE );
     folders->setCurrentItem( folders->firstChild()->firstChild()->firstChild() );
@@ -246,8 +246,8 @@ void ListViews::slotMessageChanged()
 
     QString text;
     QString tmp = msg->header().sender();
-    tmp = tmp.replace( QRegExp( "<" ), "&lt;" );
-    tmp = tmp.replace( QRegExp( ">" ), "&gt;" );
+    tmp = tmp.replace( "<", "&lt;" );
+    tmp = tmp.replace( ">", "&gt;" );
     text = QString( "<b><i>From:</i></b> <a href=\"mailto:info@trolltech.com\">%1</a><br>"
 		    "<b><i>Subject:</i></b> <big><big><b>%2</b></big></big><br>"
 		    "<b><i>Date:</i></b> %3<br><br>"
