@@ -1,7 +1,7 @@
 /****************************************************************************
-** $Id$
+** $Id: qt/main.h   3.2.1   edited May 13 09:08 $
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2002 Trolltech AS.  All rights reserved.
 **
 ** This file is part of an example program for Qt.  This example
 ** program may be used, distributed and modified without limitation.
@@ -17,10 +17,7 @@
 #include <qsqldatabase.h>
 #include <qsqlcursor.h>
 #include <qsqlform.h>
-#include "../login.h"
-
-bool createConnections();
-
+#include "../connection.h"
 
 class FormDialog : public QDialog
 {
