@@ -1,13 +1,11 @@
 /****************************************************************************
-** $Id:  qt/msvc_dsp.h   3.0.5   edited Nov 19 2001 $
+** $Id: qt/msvc_dsp.h   3.2.1   edited May 30 12:58 $
 **
-** Definition of ________ class.
+** Definition of DspMakefileGenerator class.
 **
-** Created : 970521
+** Copyright (C) 1992-2003 Trolltech AS.  All rights reserved.
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
-**
-** This file is part of the network module of the Qt GUI Toolkit.
+** This file is part of qmake.
 **
 ** This file may be distributed under the terms of the Q Public License
 ** as defined by Trolltech AS of Norway and appearing in the file
@@ -34,25 +32,31 @@
 ** not clear to you.
 **
 **********************************************************************/
-#ifndef __DSPMAKE_H__
-#define __DSPMAKE_H__
+
+#ifndef __MSVC_DSP_H__
+#define __MSVC_DSP_H__
 
 #include "winmakefile.h"
+#include <qvaluestack.h>
 
 class DspMakefileGenerator : public Win32MakefileGenerator
 {
+    QString currentGroup;
+    void beginGroupForFile(QString file, QTextStream &, const QString& filter="");
+    void endGroups(QTextStream &);
+
     bool init_flag;
     bool writeDspParts(QTextStream &);
 
     bool writeMakefile(QTextStream &);
-    QString findTemplate(QString file);
+    QString findTemplate(const QString &file);
     void init();
 
 public:
     DspMakefileGenerator(QMakeProject *p);
     ~DspMakefileGenerator();
 
-    QString defaultMakefile() const;
+    bool openOutput(QFile &file) const;
 
 protected:
     virtual void processPrlVariable(const QString &, const QStringList &);
@@ -62,12 +66,7 @@ protected:
 inline DspMakefileGenerator::~DspMakefileGenerator()
 { }
 
-inline QString DspMakefileGenerator::defaultMakefile() const
-{
-    return project->first("TARGET") + project->first("DSP_EXTENSION");
-}
-
 inline bool DspMakefileGenerator::findLibraries()
 { return Win32MakefileGenerator::findLibraries("MSVCDSP_LIBS"); }
 
-#endif /* __DSPMAKE_H__ */
+#endif /* __MSVC_DSP_H__ */
