@@ -1,13 +1,11 @@
 /****************************************************************************
-** $Id: qt/msvc_nmake.cpp   3.1.2   edited Jan 16 01:05 $
+** $Id: qt/msvc_nmake.cpp   3.2.1   edited Jun 30 03:11 $
 **
-** Definition of ________ class.
+** Implementation of NmakeMakefileGenerator class.
 **
-** Created : 970521
+** Copyright (C) 1992-2003 Trolltech AS.  All rights reserved.
 **
-** Copyright (C) 1992-2002 Trolltech AS.  All rights reserved.
-**
-** This file is part of the network module of the Qt GUI Toolkit.
+** This file is part of qmake.
 **
 ** This file may be distributed under the terms of the Q Public License
 ** as defined by Trolltech AS of Norway and appearing in the file
@@ -206,8 +204,8 @@ NmakeMakefileGenerator::writeNmakeParts(QTextStream &t)
     }
 
     t << "####### Build rules" << endl << endl;
-    t << "all: " << varGlue("ALL_DEPS",""," "," ") << "$(TARGET)" << endl << endl;
-    t << "$(TARGET): " << var("PRE_TARGETDEPS") << " $(UICDECLS) $(OBJECTS) $(OBJMOC) " 
+    t << "all: " << fileFixify(Option::output.name()) << " " << varGlue("ALL_DEPS"," "," "," ") << "$(TARGET)" << endl << endl;
+    t << "$(TARGET): " << var("PRE_TARGETDEPS") << " $(UICDECLS) $(OBJECTS) $(OBJMOC) "
       << var("POST_TARGETDEPS");
     if(!project->variables()["QMAKE_APP_OR_DLL"].isEmpty()) {
 	t << "\n\t" << "$(LINK) $(LFLAGS) /OUT:$(TARGET) @<< " << "\n\t  "
@@ -222,7 +220,7 @@ NmakeMakefileGenerator::writeNmakeParts(QTextStream &t)
     if(project->isActiveConfig("dll") && !project->variables()["DLLDESTDIR"].isEmpty()) {
 	QStringList dlldirs = project->variables()["DLLDESTDIR"];
 	for ( QStringList::Iterator dlldir = dlldirs.begin(); dlldir != dlldirs.end(); ++dlldir ) {
-	    t << "\n\t" << "-copy $(TARGET) " << *dlldir;
+	    t << "\n\t" << "-$(COPY_FILE) $(TARGET) " << *dlldir;
 	}
     }
     QString targetfilename = project->variables()["TARGET"].first();
@@ -250,31 +248,49 @@ NmakeMakefileGenerator::writeNmakeParts(QTextStream &t)
 	  << var("QMAKE_RC") << " " << var("RC_FILE") << endl << endl;
     }
 
-    t << "mocables: $(SRCMOC)" << endl << endl;
+    t << "mocables: $(SRCMOC)" << endl
+      << "uicables: $(UICIMPLS) $(UICDECLS)" << endl << endl;
 
     writeMakeQmake(t);
 
+    QStringList dist_files = Option::mkfile::project_files;
+    if(!project->isEmpty("QMAKE_INTERNAL_INCLUDED_FILES"))
+	dist_files += project->variables()["QMAKE_INTERNAL_INCLUDED_FILES"];
+    if(!project->isEmpty("TRANSLATIONS"))
+	dist_files << var("TRANSLATIONS");
+    if(!project->isEmpty("FORMS")) {
+	QStringList &forms = project->variables()["FORMS"];
+	for(QStringList::Iterator formit = forms.begin(); formit != forms.end(); ++formit) {
+	    QString ui_h = fileFixify((*formit) + Option::h_ext.first());
+	    if(QFile::exists(ui_h) )
+		dist_files << ui_h;
+	}
+    }
     t << "dist:" << "\n\t"
-      << "$(ZIP) " << var("PROJECT") << ".zip "
-      << var("PROJECT") << ".pro $(SOURCES) $(HEADERS) $(DIST) $(FORMS)" << endl << endl;
+      << "$(ZIP) " << var("QMAKE_ORIG_TARGET") << ".zip " << "$(SOURCES) $(HEADERS) $(DIST) $(FORMS) "
+      << dist_files.join(" ") << " " << var("TRANSLATIONS") << " " << var("IMAGES") << endl << endl;
 
-    t << "clean:"
-      << varGlue("OBJECTS","\n\t-del ","\n\t-del ","")
-      << varGlue("SRCMOC" ,"\n\t-del ","\n\t-del ","")
-      << varGlue("OBJMOC" ,"\n\t-del ","\n\t-del ","")
-      << varGlue("UICDECLS" ,"\n\t-del ","\n\t-del ","")
-      << varGlue("UICIMPLS" ,"\n\t-del ","\n\t-del ","")
-      << varGlue("QMAKE_CLEAN","\n\t-del ","\n\t-del ","")
-      << varGlue("CLEAN_FILES","\n\t-del ","\n\t-del ","");
-    
+    t << "uiclean:"
+      << varGlue("UICDECLS" ,"\n\t-$(DEL_FILE) ","\n\t-$(DEL_FILE) ","")
+      << varGlue("UICIMPLS" ,"\n\t-$(DEL_FILE) ","\n\t-$(DEL_FILE) ","") << endl;
+
+    t << "mocclean:"
+      << varGlue("SRCMOC" ,"\n\t-$(DEL_FILE) ","\n\t-$(DEL_FILE) ","")
+      << varGlue("OBJMOC" ,"\n\t-$(DEL_FILE) ","\n\t-$(DEL_FILE) ","") << endl;
+
+    t << "clean: uiclean mocclean"
+      << varGlue("OBJECTS","\n\t-$(DEL_FILE) ","\n\t-$(DEL_FILE) ","")
+      << varGlue("QMAKE_CLEAN","\n\t-$(DEL_FILE) ","\n\t-$(DEL_FILE) ","\n")
+      << varGlue("CLEAN_FILES","\n\t-$(DEL_FILE) ","\n\t-$(DEL_FILE) ","\n");
     if ( project->isActiveConfig("activeqt")) {
-	t << ("\n\t-del tmp\\" + targetfilename + ".*");
-	t << "\n\t-del tmp\\dump.*";
+	t << ("\n\t-$(DEL_FILE) tmp\\" + targetfilename + ".*");
+	t << "\n\t-$(DEL_FILE) tmp\\dump.*";
     }
     if(!project->isEmpty("IMAGES"))
-	t << varGlue("QMAKE_IMAGE_COLLECTION", "\n\t-del ", "\n\t-del ", "");
+	t << varGlue("QMAKE_IMAGE_COLLECTION", "\n\t-$(DEL_FILE) ", "\n\t-$(DEL_FILE) ", "");
+    t << endl;
 
-    // blasted user defined targets
+    // user defined targets
     QStringList &qut = project->variables()["QMAKE_EXTRA_WIN_TARGETS"];
     for(QStringList::Iterator it = qut.begin(); it != qut.end(); ++it) {
 	QString targ = var((*it) + ".target"),
@@ -288,14 +304,19 @@ NmakeMakefileGenerator::writeNmakeParts(QTextStream &t)
 		dep = (*dep_it);
 	    deps += " " + dep;
 	}
+	if(!project->variables()["QMAKE_NOFORCE"].isEmpty() && 
+	   project->variables()[(*it) + ".CONFIG"].findIndex("phony") != -1)
+	    deps += QString(" ") + "FORCE";
 	t << "\n\n" << targ << ":" << deps << "\n\t"
 	  << cmd;
     }
-
     t << endl << endl;
 
+    if(project->variables()["QMAKE_NOFORCE"].isEmpty())
+	t << "FORCE:" << endl << endl;
+
     t << "distclean: clean"
-      << "\n\t-del $(TARGET)"
+      << "\n\t-$(DEL_FILE) $(TARGET)"
       << endl << endl;
 }
 
@@ -330,6 +351,12 @@ NmakeMakefileGenerator::init()
 	project->variables()["DEFINES"].append("QT_DLL");
     if (project->isActiveConfig("qt_dll"))
 	if(configs.findIndex("qt") == -1) configs.append("qt");
+    if ( project->isActiveConfig("qtopia") ) {
+	if(configs.findIndex("qtopialib") == -1)
+	    configs.append("qtopialib");
+	if(configs.findIndex("qtopiainc") == -1)
+	    configs.append("qtopiainc");
+    }
     if ( project->isActiveConfig("qt") ) {
 	if ( project->isActiveConfig( "plugin" ) ) {
 	    project->variables()["CONFIG"].append("dll");
@@ -401,6 +428,13 @@ NmakeMakefileGenerator::init()
 	project->variables()["INCLUDEPATH"] += project->variables()["QMAKE_INCDIR"];
     if ( project->isActiveConfig("qt") || project->isActiveConfig("opengl") )
 	project->variables()["CONFIG"].append("windows");
+    if ( project->isActiveConfig("qtopiainc") )
+	project->variables()["INCLUDEPATH"] += project->variables()["QMAKE_INCDIR_QTOPIA"];
+    if ( project->isActiveConfig("qtopialib") ) {
+	if(!project->isEmpty("QMAKE_LIBDIR_QTOPIA"))
+	    project->variables()["QMAKE_LIBDIR"] += project->variables()["QMAKE_LIBDIR_QTOPIA"];
+	project->variables()["QMAKE_LIBS"] += project->variables()["QMAKE_LIBS_QTOPIA"];
+    }
     if ( project->isActiveConfig("qt") ) {
 	project->variables()["CONFIG"].append("moc");
 	project->variables()["INCLUDEPATH"] +=	project->variables()["QMAKE_INCDIR_QT"];
@@ -508,6 +542,17 @@ NmakeMakefileGenerator::init()
     if ( project->isActiveConfig("moc") )
 	setMocAware(TRUE);
     project->variables()["QMAKE_LIBS"] += project->variables()["LIBS"];
+
+    QStringList &libs = project->variables()["QMAKE_LIBS"];
+    for ( QStringList::Iterator libit = libs.begin(); libit != libs.end(); ++libit ) {
+	if (  (*libit).startsWith( "-l" ) ) {
+	    (*libit) = (*libit).mid( 2 ) + ".lib";
+	} else if ( (*libit).startsWith( "-L" ) ) {
+	    project->variables()["QMAKE_LIBDIR"] += (*libit).mid(2);
+	    libit = libs.remove( libit );
+	}
+    }
+
     project->variables()["QMAKE_FILETAGS"] += QStringList::split(' ',
 	"HEADERS SOURCES DEF_FILE RC_FILE TARGET QMAKE_LIBS DESTDIR DLLDESTDIR INCLUDEPATH");
     QStringList &l = project->variables()["QMAKE_FILETAGS"];
