@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id:  qt/qcolordialog.cpp   3.0.5   edited Jun 7 16:44 $
+** $Id: qt/qcolordialog.cpp   3.2.1   edited May 24 15:31 $
 **
 ** Implementation of QColorDialog class
 **
 ** Created : 990222
 **
-** Copyright (C) 1999-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1999-2002 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the dialogs module of the Qt GUI Toolkit.
 **
@@ -53,6 +53,7 @@
 #include "qapplication.h"
 #include "qstyle.h"
 #include "qsettings.h"
+#include "qpopupmenu.h"
 
 #ifdef Q_WS_MAC
 QRgb macGetRgba( QRgb initial, bool *ok, QWidget *parent, const char* name );
@@ -128,14 +129,13 @@ struct QWellArrayData {
     QBrush *brush;
 };
 
-// NOT REVISED
-/* WARNING, NOT DOCUMENTED
-  \class QWellArray qwellarray_p.h
-  \brief ....
+/*!
+    \internal
+    \class QWellArray qwellarray_p.h
+    \brief The QWellArray class provides a well array.
 
-  ....
 
-  \ingroup advanced
+    \ingroup advanced
 */
 
 QWellArray::QWellArray( QWidget *parent, const char * name, bool popup )
@@ -320,9 +320,8 @@ void QWellArray::setSelected( int row, int col )
     if ( row >= 0 )
 	emit selected( row, col );
 
-    if ( isVisible() && parentWidget() && parentWidget()->inherits("QPopupMenu") )
+    if ( isVisible() && ::qt_cast<QPopupMenu*>(parentWidget()) )
 	parentWidget()->close();
-
 }
 
 
@@ -449,8 +448,8 @@ static void initRGB()
 }
 
 /*!
-  Returns the number of custom colors supported by
-  QColorDialog. All color dialogs share the same custom colors.
+    Returns the number of custom colors supported by QColorDialog. All
+    color dialogs share the same custom colors.
 */
 int QColorDialog::customCount()
 {
@@ -458,8 +457,8 @@ int QColorDialog::customCount()
 }
 
 /*!
-  Returns custom color number \a i as a QRgb.
- */
+    Returns custom color number \a i as a QRgb.
+*/
 QRgb QColorDialog::customColor( int i )
 {
     initRGB();
@@ -473,14 +472,14 @@ QRgb QColorDialog::customColor( int i )
 }
 
 /*!
-  Sets custom color number \a i to the QRgb value \a c.
+    Sets custom color number \a i to the QRgb value \a c.
 */
 void QColorDialog::setCustomColor( int i, QRgb c )
 {
     initRGB();
     if ( i < 0 || i >= customCount() ) {
 #ifdef QT_CHECK_RANGE
-	qWarning( "QColorDialog::customColor() index %d out of range", i );
+	qWarning( "QColorDialog::setCustomColor() index %d out of range", i );
 #endif
 	return;
     }
@@ -488,6 +487,22 @@ void QColorDialog::setCustomColor( int i, QRgb c )
     cusrgb[i] = c;
 }
 
+/*!
+    Sets standard color number \a i to the QRgb value \a c.
+*/
+
+void QColorDialog::setStandardColor( int i, QRgb c )
+{
+    initRGB();
+    if ( i < 0 || i >= 6*8 ) {
+#ifdef QT_CHECK_RANGE
+	qWarning( "QColorDialog::setStandardColor() index %d out of range", i );
+#endif
+	return;
+    }
+    stdrgb[i] = c;
+}
+
 static inline void rgb2hsv( QRgb rgb, int&h, int&s, int&v )
 {
     QColor c;
@@ -890,8 +905,8 @@ public:
     QColNumLineEdit( QWidget *parent, const char* name=0 )
 	: QLineEdit( parent, name ) { setMaxLength( 3 );}
     QSize sizeHint() const {
-	return QSize( 30, //#####
-		     QLineEdit::sizeHint().height() ); }
+	return QSize( fontMetrics().width( "999" ) + 2 * ( margin() + frameWidth() ),
+		      QLineEdit::sizeHint().height() ); }
     void setNum( int i ) {
 	QString s;
 	s.setNum(i);
@@ -1126,6 +1141,7 @@ QColorShower::QColorShower( QWidget *parent, const char *name )
     connect( rEd, SIGNAL(textChanged(const QString&)), this, SLOT(rgbEd()) );
     connect( gEd, SIGNAL(textChanged(const QString&)), this, SLOT(rgbEd()) );
     connect( bEd, SIGNAL(textChanged(const QString&)), this, SLOT(rgbEd()) );
+    connect( alphaEd, SIGNAL(textChanged(const QString&)), this, SLOT(rgbEd()) );
 }
 
 void QColorShower::showCurrentColor()
@@ -1137,7 +1153,11 @@ void QColorShower::showCurrentColor()
 void QColorShower::rgbEd()
 {
     rgbOriginal = TRUE;
-    curCol = qRgb( rEd->val(), gEd->val(), bEd->val() );
+    if ( alphaEd->isVisible() )
+	curCol = qRgba( rEd->val(), gEd->val(), bEd->val(), currentAlpha() );
+    else
+	curCol = qRgb( rEd->val(), gEd->val(), bEd->val() );
+
     rgb2hsv(currentColor(), hue, sat, val );
 
     hEd->setNum( hue );
@@ -1197,7 +1217,6 @@ void QColorShower::setHsv( int h, int s, int v )
     gEd->setNum( qGreen(currentColor()) );
     bEd->setNum( qBlue(currentColor()) );
 
-
     showCurrentColor();
 }
 
@@ -1223,7 +1242,7 @@ public slots:
 public:
     QWellArray *custom;
     QWellArray *standard;
-private:
+
     QColorPicker *cp;
     QColorLuminancePicker *lp;
     QColorShower *cs;
@@ -1385,13 +1404,13 @@ void QColorDialogPrivate::addCustom()
 
 /*!
     \class QColorDialog qcolordialog.h
+    \brief The QColorDialog class provides a dialog widget for specifying colors.
+    \mainclass
     \ingroup dialogs
     \ingroup graphics
-    \mainclass
-    \brief The QColorDialog class provides a dialog widget for specifying colors.
 
-    The color dialog's function is to allow users to choose colors -
-    for instance, you might use this in a drawing program to allow the
+    The color dialog's function is to allow users to choose colors.
+    For example, you might use this in a drawing program to allow the
     user to set the brush color.
 
     The static functions provide modal color dialogs.
@@ -1409,22 +1428,25 @@ void QColorDialogPrivate::addCustom()
     during the execution of the program. Use setCustomColor() to set
     the custom colors, and use customColor() to get them.
 
-    <img src=qcolordlg-w.png>
+    \img qcolordlg-w.png
 */
 
-/*!  Constructs a default color dialog with parent \a parent and called \a
- name. If \a modal is TRUE the dialog will be modal. Use setColor() to
- set an initial value.
+/*!
+    Constructs a default color dialog with parent \a parent and called
+    \a name. If \a modal is TRUE the dialog will be modal. Use
+    setColor() to set an initial value.
 
-  \sa getColor()
+    \sa getColor()
 */
 
 QColorDialog::QColorDialog(QWidget* parent, const char* name, bool modal) :
-    QDialog(parent, name, modal, WStyle_Customize | WStyle_Title | WStyle_DialogBorder | WStyle_SysMenu )
+    QDialog(parent, name, modal, (  WType_Dialog | WStyle_Customize | WStyle_Title |
+                                    WStyle_DialogBorder | WStyle_SysMenu ) )
 {
     setSizeGripEnabled( FALSE );
     d = new QColorDialogPrivate( this );
 
+#ifndef QT_NO_SETTINGS
     if ( !customSet ) {
 	QSettings settings;
 	settings.insertSearchPath( QSettings::Windows, "/Trolltech" );
@@ -1435,16 +1457,16 @@ QColorDialog::QColorDialog(QWidget* parent, const char* name, bool modal) :
 		cusrgb[i] = rgb;
 	}
     }
+#endif
 }
 
-
 /*!
-  Pops up a modal color dialog, lets the user choose a color, and
-  returns that color. The color is initially set to \a initial. The
-  dialog is a child of \a parent and is called \a name. Returns an
-  invalid (see QColor::isValid()) color if the user cancels the dialog.
-  All colors allocated by the dialog will be deallocated before this
-  function returns.
+    Pops up a modal color dialog, lets the user choose a color, and
+    returns that color. The color is initially set to \a initial. The
+    dialog is a child of \a parent and is called \a name. It returns
+    an invalid (see QColor::isValid()) color if the user cancels the
+    dialog. All colors allocated by the dialog will be deallocated
+    before this function returns.
 */
 
 QColor QColorDialog::getColor( const QColor& initial, QWidget *parent,
@@ -1457,11 +1479,6 @@ QColor QColorDialog::getColor( const QColor& initial, QWidget *parent,
     int allocContext = QColor::enterAllocContext();
     QColorDialog *dlg = new QColorDialog( parent, name, TRUE );  //modal
 #ifndef QT_NO_WIDGET_TOPEXTRA
-    if ( parent && parent->icon() && !parent->icon()->isNull() )
-	dlg->setIcon( *parent->icon() );
-    else if ( qApp->mainWidget() && qApp->mainWidget()->icon() && !qApp->mainWidget()->icon()->isNull() )
-	dlg->setIcon( *qApp->mainWidget()->icon() );
-
     dlg->setCaption( QColorDialog::tr( "Select color" ) );
 #endif
     dlg->setColor( initial );
@@ -1478,15 +1495,15 @@ QColor QColorDialog::getColor( const QColor& initial, QWidget *parent,
 
 
 /*!
-  Pops up a modal color dialog to allow the user to choose a color and
-  an alpha channel (transparency) value. The color+alpha is initially
-  set to \a initial. The dialog is a child of \a parent and called \a
-  name.
+    Pops up a modal color dialog to allow the user to choose a color
+    and an alpha channel (transparency) value. The color+alpha is
+    initially set to \a initial. The dialog is a child of \a parent
+    and called \a name.
 
-  If \a ok is non-null, \e *\a ok is set to TRUE if the user clicked OK,
-  and to FALSE if the user clicked Cancel.
+    If \a ok is non-null, \e *\a ok is set to TRUE if the user clicked
+    OK, and to FALSE if the user clicked Cancel.
 
-  If the user clicks Cancel, the \a initial value is returned.
+    If the user clicks Cancel, the \a initial value is returned.
 */
 
 QRgb QColorDialog::getRgba( QRgb initial, bool *ok,
@@ -1498,6 +1515,11 @@ QRgb QColorDialog::getRgba( QRgb initial, bool *ok,
 
     int allocContext = QColor::enterAllocContext();
     QColorDialog *dlg = new QColorDialog( parent, name, TRUE );  //modal
+
+    Q_CHECK_PTR( dlg );
+#ifndef QT_NO_WIDGET_TOPEXTRA
+    dlg->setCaption( QColorDialog::tr( "Select color" ) );
+#endif
     dlg->setColor( initial );
     dlg->selectColor( initial );
     dlg->setSelectedAlpha( qAlpha(initial) );
@@ -1522,9 +1544,9 @@ QRgb QColorDialog::getRgba( QRgb initial, bool *ok,
 
 
 /*!
-  Returns the color currently selected in the dialog.
+    Returns the color currently selected in the dialog.
 
-  \sa setColor()
+    \sa setColor()
 */
 
 QColor QColorDialog::color() const
@@ -1533,25 +1555,27 @@ QColor QColorDialog::color() const
 }
 
 
-/*! Destroys the dialog and frees any memory it allocated.
-
+/*!
+    Destroys the dialog and frees any memory it allocated.
 */
 
 QColorDialog::~QColorDialog()
 {
+#ifndef QT_NO_SETTINGS
     if ( !customSet ) {
 	QSettings settings;
 	settings.insertSearchPath( QSettings::Windows, "/Trolltech" );
 	for ( int i = 0; i < 2*8; ++i )
 	    settings.writeEntry( "/Qt/customColors/" + QString::number( i ), (int)cusrgb[i] );
     }
+#endif
 }
 
 
 /*!
-  Sets the color shown in the dialog to \a c.
+    Sets the color shown in the dialog to \a c.
 
-  \sa color()
+    \sa color()
 */
 
 void QColorDialog::setColor( const QColor& c )
@@ -1563,8 +1587,8 @@ void QColorDialog::setColor( const QColor& c )
 
 
 /*!
-  Sets the initial alpha channel value to \a a, and shows the alpha channel
-  entry box.
+    Sets the initial alpha channel value to \a a, and shows the alpha
+    channel entry box.
 */
 
 void QColorDialog::setSelectedAlpha( int a )
@@ -1575,7 +1599,7 @@ void QColorDialog::setSelectedAlpha( int a )
 
 
 /*!
-  Returns the value selected for the alpha channel.
+    Returns the value selected for the alpha channel.
 */
 
 int QColorDialog::selectedAlpha() const
@@ -1584,7 +1608,7 @@ int QColorDialog::selectedAlpha() const
 }
 
 /*!
-  Sets focus to the corresponding button, if any.
+    Sets focus to the corresponding button, if any.
 */
 bool QColorDialog::selectColor( const QColor& col )
 {
