@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id:  qt/qerrormessage.h   3.0.5   edited Oct 12 2001 $
+** $Id: qt/qerrormessage.h   3.2.1   edited May 13 09:08 $
 **
 ** Definition of a nice qInstallErrorMessage() handler
 **
-** Created : 2000-05-27, after Kalle Dalheimer's birthday
+** Created : 000527, after Kalle Dalheimer's birthday
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2002 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the dialogs module of the Qt GUI Toolkit.
 **
@@ -35,8 +35,8 @@
 **
 **********************************************************************/
 
-#ifndef QERRORHANDLER_H
-#define QERRORHANDLER_H
+#ifndef QERRORMESSAGE_H
+#define QERRORMESSAGE_H
 
 #ifndef QT_H
 #include "qdialog.h"
@@ -74,6 +74,11 @@ private:
     QDict<int> * doNotShow;
 
     bool nextPending();
+
+#if defined(Q_DISABLE_COPY) // Disabled copy constructor and operator=
+    QErrorMessage( const QErrorMessage & );
+    QErrorMessage &operator=( const QErrorMessage & );
+#endif
 };
 
 #endif //QT_NO_ERRORMESSAGE
