@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qbitmap.cpp   3.1.2   edited Nov 8 14:37 $
+** $Id: qt/qbitmap.cpp   3.2.1   edited May 13 09:08 $
 **
 ** Implementation of QBitmap class
 **
@@ -190,7 +190,7 @@ QBitmap::QBitmap( const QBitmap &bitmap )
 
 #ifndef QT_NO_IMAGEIO
 /*!
-    Constructs a pixmap from the file \a fileName. If the file does
+    Constructs a bitmap from the file \a fileName. If the file does
     not exist or is of an unknown format, the bitmap becomes a null
     bitmap.
 
