@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id:  qt/qsimplerichtext.cpp   3.0.5   edited Jun 7 14:39 $
+** $Id: qt/qsimplerichtext.cpp   3.2.1   edited May 13 09:08 $
 **
 ** Implementation of the QSimpleRichText class
 **
 ** Created : 990101
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2002 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
@@ -51,23 +51,8 @@ public:
     void adjustSize();
 };
 
-static uint int_sqrt(uint n)
-{
-    uint h, p= 0, q= 1, r= n;
-    Q_ASSERT( n < 1073741824U );  // UINT_MAX>>2 on 32-bits architecture
-    while ( q <= n )
-	q <<= 2;
-    while ( q != 1 ) {
-	q >>= 2;
-	h= p + q;
-	p >>= 1;
-	if ( r >= h ) {
-	    p += q;
-	    r -= h;
-	}
-    }
-    return p;
-}
+// Pull this private function in from qglobal.cpp
+extern unsigned int qt_int_sqrt( unsigned int n );
 
 void QSimpleRichTextData::adjustSize() {
     QFontMetrics fm( font );
@@ -75,11 +60,11 @@ void QSimpleRichTextData::adjustSize() {
     int w = mw;
     doc->doLayout( 0,w );
     if ( doc->widthUsed() != 0 ) {
-	w = int_sqrt( 5 * doc->height() * doc->widthUsed() / 3 );
+	w = qt_int_sqrt( 5 * doc->height() * doc->widthUsed() / 3 );
 	doc->doLayout( 0, QMIN( w, mw) );
 
 	if ( w*3 < 5*doc->height() ) {
-	    w = int_sqrt( 2 * doc->height() * doc->widthUsed() );
+	    w = qt_int_sqrt( 2 * doc->height() * doc->widthUsed() );
 	    doc->doLayout( 0,QMIN(w, mw ) );
 	}
     }
@@ -201,7 +186,9 @@ QSimpleRichText::QSimpleRichText( const QString& text, const QFont& fnt,
     d->doc->setDefaultFormat( fnt, QColor() );
     d->doc->flow()->setPageSize( pageBreak );
     d->doc->setPageBreakEnabled( TRUE );
+#ifndef QT_NO_MIME
     d->doc->setMimeSourceFactory( (QMimeSourceFactory*)factory );
+#endif
     d->doc->setUnderlineLinks( linkUnderline );
     d->doc->setText( text, context );
 }
@@ -228,6 +215,7 @@ void QSimpleRichText::setWidth( int w )
 {
     if ( w == d->cachedWidth && !d->cachedWidthWithPainter )
 	return;
+    d->doc->formatter()->setAllowBreakInWords( d->doc->isPageBreakEnabled() );
     d->cachedWidth = w;
     d->cachedWidthWithPainter = FALSE;
     d->doc->doLayout( 0, w );
@@ -248,6 +236,9 @@ void QSimpleRichText::setWidth( QPainter *p, int w )
 {
     if ( w == d->cachedWidth  && d->cachedWidthWithPainter )
 	return;
+    d->doc->formatter()->setAllowBreakInWords( d->doc->isPageBreakEnabled() ||
+		       p && p->device() &&
+		     p->device()->devType() == QInternal::Printer );
     p->save();
     d->cachedWidth = w;
     d->cachedWidthWithPainter = TRUE;
@@ -314,9 +305,10 @@ void QSimpleRichText::adjustSize()
 /*!
     Draws the formatted text with painter \a p, at position (\a x, \a
     y), clipped to \a clipRect. The clipping rectangle is given in the
-    rich text object's coordinates translated by (\a x, \a y). Colors
-    from the color group \a cg are used as needed, and if not 0, \a
-    *paper is used as the background brush.
+    rich text object's coordinates translated by (\a x, \a y). Passing
+    an null rectangle results in no clipping. Colors from the color
+    group \a cg are used as needed, and if not 0, \a *paper is used as
+    the background brush.
 
     Note that the display code is highly optimized to reduce flicker,
     so passing a brush for \a paper is preferable to simply clearing
