@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qsound.cpp   3.0.5   edited Jul 3 18:57 $
+** $Id: qt/qsound.cpp   3.2.1   edited May 13 09:08 $
 **
 ** Implementation of QSound class and QAuServer internal class
 **
@@ -180,10 +180,17 @@ QSound::~QSound()
 
 /*!
     Returns TRUE if the sound has finished playing; otherwise returns FALSE.
+
+    Note: On Windows this will always return TRUE as there is no way to determine
+    when the sound has finished.
 */
 bool QSound::isFinished() const
 {
+#ifdef Q_OS_WIN
+    return TRUE;
+#else
     return d->looprem == 0;
+#endif
 }
 
 /*!
