@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id$
+** $Id: qt/qstyle.cpp   3.2.1   edited Jul 8 11:10 $
 **
 ** Implementation of QStyle class
 **
 ** Created : 981231
 **
-** Copyright (C) 1998-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1998-2002 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
@@ -34,6 +34,7 @@
 ** not clear to you.
 **
 **********************************************************************/
+
 #include "qstyle.h"
 #ifndef QT_NO_STYLE
 #include "qapplication.h"
@@ -71,8 +72,8 @@ public:
     QStyle functions to see the meaning of the arguments.
 
     When calling QStyle functions from your own widgets, you must only
-    pass either the default QStyleOption or the argument that QStyle
-    is documented to accept. For example, if the function expects
+    pass the default QStyleOption or the argument that QStyle is
+    documented to accept. For example, if the function expects
     QStyleOption(QMenuItem *, int), passing QStyleOption(QMenuItem *)
     leaves the optional integer argument uninitialized.
 
@@ -103,6 +104,12 @@ public:
     argument to QStyle functions.
 */
 
+/*!
+    \fn QStyleOption::QStyleOption(int)
+
+    Pass one integer, \a in1. For example, headerSection.
+*/
+
 /*!
     \fn QStyleOption::QStyleOption(int, int)
 
@@ -158,6 +165,24 @@ public:
     Pass an Qt::ArrowType, \a a.
 */
 
+/*!
+    \fn QStyleOption::QStyleOption(QCheckListItem* i)
+
+    Pass a QCheckListItem, \a i.
+*/
+
+/*!
+    \fn QStyleOption::QStyleOption( const QRect &r )
+
+    Pass a QRect, \a r.
+*/
+
+/*!
+    \fn QStyleOption::QStyleOption( QWidget *w )
+
+    Pass a QWidget, \a w.
+*/
+
 /*!
     \fn bool QStyleOption::isDefault() const
 
@@ -215,6 +240,13 @@ public:
     called; otherwise the return value is undefined.
 */
 
+/*!
+    \fn int QStyleOption::headerSection() const
+
+    Returns the header section if the appropriate constructor was
+    called; otherwise the return value is undefined.
+*/
+
 /*!
     \fn const QColor& QStyleOption::color() const
 
@@ -243,6 +275,27 @@ public:
     otherwise the return value is undefined.
 */
 
+/*!
+    \fn QCheckListItem* QStyleOption::checkListItem() const
+
+    Returns a check list item if the appropriate constructor was
+    called; otherwise the return value is undefined.
+*/
+
+/*!
+    \fn QRect QStyleOption::rect() const
+
+    Returns a rectangle if the appropriate constructor was called;
+    otherwise the return value is undefined.
+*/
+
+/*!
+    \fn QWidget* QStyleOption::widget() const
+
+    Returns a pointer to a widget if the appropriate constructor was called;
+    otherwise the return value is undefined.
+*/
+
 /*!
     \class QStyle qstyle.h
     \brief The QStyle class specifies the look and feel of a GUI.
@@ -323,7 +376,7 @@ public:
     \value UI_AnimateCombo
     \value UI_AnimateTooltip
     \value UI_FadeTooltip
-
+    \value UI_AnimateToolBox Reserved
 */
 
 /*!
@@ -526,10 +579,15 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
 	QPixmap  pm( *pixmap );
 	bool clip = (flags & Qt::DontClip) == 0;
 	if ( clip ) {
-	    if ( pm.width() < w && pm.height() < h )
+	    if ( pm.width() < w && pm.height() < h ) {
 		clip = FALSE;
-	    else
-		p->setClipRect( x, y, w, h );
+	    } else {
+		p->save();
+		QRegion cr = QRect(x, y, w, h);
+		if (p->hasClipping())
+		    cr &= p->clipRegion(QPainter::CoordPainter);
+		p->setClipRegion(cr);
+	    }
 	}
 	if ( (flags & Qt::AlignVCenter) == Qt::AlignVCenter )
 	    y += h/2 - pm.height()/2;
@@ -574,7 +632,7 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
 	}
 	p->drawPixmap( x, y, pm );
 	if ( clip )
-	    p->setClipping( FALSE );
+	    p->restore();
     } else if ( !text.isNull() ) {
 	if ( gs == Qt::WindowsStyle && !enabled ) {
 	    p->setPen( g.light() );
@@ -641,6 +699,7 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
     \value PE_PanelDockWindow  panel frame for dock windows and toolbars.
     \value PE_PanelTabWidget  panel frame for tab widgets.
     \value PE_PanelLineEdit  panel frame for line edits.
+    \value PE_PanelGroupBox  panel frame for group boxes.
 
     \value PE_TabBarBase  area below tabs in a tab widget, for example,
 	QTab.
@@ -656,7 +715,7 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
 
     \value PE_GroupBoxFrame  frame around a group box; see also
 	QGroupBox.
-    \value PE_WindowFrame  frame around a MDI or docking window
+    \value PE_WindowFrame  frame around a MDI window or a docking window
 
 
     \value PE_Separator  generic separator.
@@ -681,10 +740,13 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
     \value PE_ProgressBarChunk  section of a progress bar indicator; see
 	also QProgressBar.
 
-    \value PE_CustomBase  base value for custom ControlElements. All values above
-	    this are reserved for custom use. Therefore, custom values must be
-	    greater than this value.
+    \value PE_CheckListController controller part of a listview item
+    \value PE_CheckListIndicator checkbox part of a listview item
+    \value PE_CheckListExclusiveIndicator radiobutton part of a listview item
 
+    \value PE_CustomBase  base value for custom PrimitiveElements.
+	All values above this are reserved for custom use. Custom
+	values must be greater than this value.
 
     \sa drawPrimitive()
 */
@@ -818,44 +880,44 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
     a widget that performs some action or displays information to the
     user.
 
-
     \value CE_PushButton  the bevel and default indicator of a QPushButton.
     \value CE_PushButtonLabel  the label (iconset with text or pixmap)
 	of a QPushButton.
 
-
     \value CE_CheckBox  the indicator of a QCheckBox.
     \value CE_CheckBoxLabel  the label (text or pixmap) of a QCheckBox.
 
-
     \value CE_RadioButton  the indicator of a QRadioButton.
     \value CE_RadioButtonLabel  the label (text or pixmap) of a QRadioButton.
 
-
     \value CE_TabBarTab  the tab within a QTabBar (a QTab).
     \value CE_TabBarLabel  the label within a QTab.
 
-
     \value CE_ProgressBarGroove  the groove where the progress
 	indicator is drawn in a QProgressBar.
     \value CE_ProgressBarContents  the progress indicator of a QProgressBar.
     \value CE_ProgressBarLabel  the text label of a QProgressBar.
 
-
     \value CE_PopupMenuItem  a menu item in a QPopupMenu.
     \value CE_PopupMenuScroller scrolling areas in a popumenu when the
 	style supports scrolling.
+    \value CE_PopupMenuHorizontalExtra extra frame area set aside with PM_PopupMenuFrameHorizontalExtra
+    \value CE_PopupMenuVerticalExtra extra frame area set aside with PM_PopupMenuFrameVerticalExtra
 
     \value CE_MenuBarItem  a menu item in a QMenuBar.
 
     \value CE_ToolButtonLabel a tool button's label.
 
+    \value CE_MenuBarEmptyArea the empty area of a QMenuBar.
+    \value CE_DockWindowEmptyArea the empty area of a QDockWindow.
+
+    \value CE_ToolBoxTab the toolbox's tab area
+    \value CE_HeaderLabel the header's label
 
     \value CE_CustomBase  base value for custom ControlElements. All values above
 	    this are reserved for custom use. Therefore, custom values must be
 	    greater than this value.
 
-
     \sa drawControl()
 */
 
@@ -881,7 +943,7 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
     the appropriate \a widget and \a opt usage:
 
     \table
-    \header \i ControlElement \& Widget Cast
+    \header \i ControlElement<br>\& Widget Cast
 	    \i Style Flags
 	    \i Notes
 	    \i Options
@@ -934,7 +996,7 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
 
     \row \i12 \l{CE_TabBarTab}(const \l QTabBar *)
 
- 	 and
+	 and
 
 	 \l{CE_TabBarLabel}(const \l QTabBar *)
 
@@ -1062,13 +1124,22 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
 
     \value SR_ToolButtonContents area for the tool button's label.
 
+    \value SR_DialogButtonAccept area for a dialog's accept button.
+    \value SR_DialogButtonReject area for a dialog's reject button.
+    \value SR_DialogButtonApply  area for a dialog's apply button.
+    \value SR_DialogButtonHelp area for a dialog's help button.
+    \value SR_DialogButtonAll area for a dialog's all button.
+    \value SR_DialogButtonRetry area for a dialog's retry button.
+    \value SR_DialogButtonAbort area for a dialog's abort button.
+    \value SR_DialogButtonIgnore area for a dialog's ignore button.
+    \value SR_DialogButtonCustom area for a dialog's custom widget area (in button row).
 
+    \value SR_ToolBoxTabContents area for a toolbox tab's icon and label
 
     \value SR_CustomBase  base value for custom ControlElements. All values above
 	    this are reserved for custom use. Therefore, custom values must be
 	    greater than this value.
 
-
     \sa subRect()
 */
 
@@ -1133,7 +1204,6 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
 	values above this are reserved for custom use. Therefore,
 	custom values must be greater than this value.
 
-
     \sa SubControl drawComplexControl()
 */
 
@@ -1167,7 +1237,7 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
     \value SC_ComboBoxEditField  combobox edit field; see also QComboBox.
     \value SC_ComboBoxArrow  combobox arrow
     \value SC_ComboBoxFrame combobox frame
-
+    \value SC_ComboBoxListBoxPopup combobox list box
 
     \value SC_SliderGroove  special subcontrol which contains the area
 	in which the slider handle may move.
@@ -1202,7 +1272,7 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
 */
 
 /*!
-    \fn void QStyle::drawComplexControl( ComplexControl control, QPainter *p, const QWidget *widget, const QRect &r, const QColorGroup &cg, SFlags how = Style_Default, SCFlags sub = SC_All, SCFlags subActive = SC_None, const QStyleOption& opt = QStyleOption::Default ) const;
+    \fn void QStyle::drawComplexControl( ComplexControl control, QPainter *p, const QWidget *widget, const QRect &r, const QColorGroup &cg, SFlags how, SCFlags sub, SCFlags subActive, const QStyleOption& opt ) const
 
     Draws the ComplexControl \a control using the painter \a p in the
     area \a r. Colors are used from the color group \a cg. The \a sub
@@ -1229,7 +1299,7 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
     the appropriate \a widget and \a opt usage:
 
     \table
-    \header \i ComplexControl \& Widget Cast
+    \header \i ComplexControl<br>\& Widget Cast
 	    \i Style Flags
 	    \i Notes
 	    \i Options
@@ -1295,7 +1365,7 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
 */
 
 /*!
-    \fn void QStyle::drawComplexControlMask( ComplexControl control, QPainter *p, const QWidget *widget, const QRect &r, const QStyleOption& opt = QStyleOption::Default ) const;
+    \fn void QStyle::drawComplexControlMask( ComplexControl control, QPainter *p, const QWidget *widget, const QRect &r, const QStyleOption& opt ) const
 
     Draw a bitmask for the ComplexControl \a control using the painter
     \a p in the area \a r. See drawComplexControl() for an explanation
@@ -1362,24 +1432,22 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
     \value PM_ButtonShiftVertical  vertical contents shift of a button when the
 	button is down.
 
-
     \value PM_DefaultFrameWidth  default frame width, usually 2.
     \value PM_SpinBoxFrameWidth  frame width of a spin box.
-
+    \value PM_MDIFrameWidth frame width of an MDI window.
+    \value PM_MDIMinimizedWidth width of a minimized MSI window.
 
     \value PM_MaximumDragDistance  Some feels require the scrollbar or
 	other sliders to jump back to the original position when the
 	mouse pointer is too far away while dragging. A value of -1
 	disables this behavior.
 
-
     \value PM_ScrollBarExtent  width of a vertical scrollbar and the
 	height of a horizontal scrollbar.
     \value PM_ScrollBarSliderMin the minimum height of a vertical
 	scrollbar's slider and the minimum width of a horiztonal
 	scrollbar slider.
 
-
     \value PM_SliderThickness  total slider thickness.
     \value PM_SliderControlThickness  thickness of the slider handle.
     \value PM_SliderLength length of the slider.
@@ -1387,7 +1455,6 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
 	and the slider.
     \value PM_SliderSpaceAvailable  the available space for the slider to move.
 
-
     \value PM_DockWindowSeparatorExtent  width of a separator in a
 	horiztonal dock window and the height of a separator in a
 	vertical dock window.
@@ -1396,10 +1463,8 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
 	vertical dock window.
     \value PM_DockWindowFrameWidth  frame width of a dock window.
 
-
     \value PM_MenuBarFrameWidth  frame width of a menubar.
 
-
     \value PM_TabBarTabOverlap number of pixels the tabs should overlap.
     \value PM_TabBarTabHSpace extra space added to the tab width.
     \value PM_TabBarTabVSpace extra space added to the tab height.
@@ -1407,14 +1472,18 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
 	and the tab pages.
     \value PM_TabBarBaseOverlap number of pixels the tab bar overlaps
 	the tab bar base.
-
+    \value PM_TabBarTabShiftHorizontal horizontal pixel shift when a
+        tab is selected.
+    \value PM_TabBarTabShiftVertical vertical pixel shift when a
+        tab is selected.
 
     \value PM_ProgressBarChunkWidth  width of a chunk in a progress bar indicator.
 
-
     \value PM_SplitterWidth  width of a splitter.
 
     \value PM_TitleBarHeight height of the title bar.
+    \value PM_PopupMenuFrameHorizontalExtra additional border, e.g. for panels
+    \value PM_PopupMenuFrameVerticalExtra additional border, e.g. for panels
 
     \value PM_IndicatorWidth  width of a check box indicator.
     \value PM_IndicatorHeight  height of a checkbox indicator.
@@ -1422,6 +1491,19 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
     \value PM_ExclusiveIndicatorHeight  height of a radio button indicator.
 
     \value PM_PopupMenuScrollerHeight height of the scroller area in a popupmenu.
+    \value PM_PopupMenuScrollerHeight height of the scroller area in a popupmenu.
+    \value PM_CheckListButtonSize area (width/height) of the
+	checkbox/radiobutton in a QCheckListItem
+    \value PM_CheckListControllerSize area (width/height) of the
+	controller in a QCheckListItem
+
+    \value PM_DialogButtonsSeparator distance between buttons in a dialog buttons widget.
+    \value PM_DialogButtonsButtonWidth minimum width of a button in a dialog buttons widget.
+    \value PM_DialogButtonsButtonHeight minimum height of a button in a dialog buttons widget.
+
+    \value PM_HeaderMarkSize
+    \value PM_HeaderGripMargin
+    \value PM_HeaderMargin
 
     \value PM_CustomBase  base value for custom ControlElements. All
 	values above this are reserved for custom use. Therefore,
@@ -1470,12 +1552,19 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
     \value CT_DockWindow
     \value CT_ProgressBar
     \value CT_PopupMenuItem
-
+    \value CT_TabBarTab
+    \value CT_Slider
+    \value CT_Header
+    \value CT_LineEdit
+    \value CT_MenuBar
+    \value CT_SpinBox
+    \value CT_SizeGrip
+    \value CT_TabWidget
+    \value CT_DialogButtons
 
     \value CT_CustomBase  base value for custom ControlElements. All
-	values above this are reserved for custom use. Therefore,
-	custom values must be greater than this value.
-
+	values above this are reserved for custom use. Custom values
+	must be greater than this value.
 
     \sa sizeFromContents()
 */
@@ -1533,6 +1622,11 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
 	jump to that position. If FALSE, the middle clicking is
 	ignored.
 
+    \value SH_ScrollBar_LeftClickAbsolutePosition  a boolean value.
+	If TRUE, left clicking on a scrollbar causes the slider to
+	jump to that position. If FALSE, the left clicking will
+	behave as appropriate for each control.
+
     \value SH_ScrollBar_ScrollWhenPointerLeavesControl  a boolean
 	value. If TRUE, when clicking a scrollbar SubControl, holding
 	the mouse button down and moving the pointer outside the
@@ -1540,7 +1634,6 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
 	scollbar stops scrolling when the pointer leaves the
 	SubControl.
 
-
     \value SH_TabBar_Alignment  the alignment for tabs in a
 	QTabWidget. Possible values are \c Qt::AlignLeft, \c
 	Qt::AlignCenter and \c Qt::AlignRight.
@@ -1581,6 +1674,12 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
     \value SH_PopupMenu_SubMenuPopupDelay  the number of milliseconds
 	to wait before opening a submenu; 256 on windows, 96 on Motif.
 
+    \value SH_PopupMenu_Scrollable whether popupmenu's must support
+	scrolling.
+
+    \value SH_PopupMenu_SloppySubMenus whether popupmenu's must support
+	sloppy submenu; as implemented on Mac OS.
+
     \value SH_ScrollView_FrameOnlyAroundContents  whether scrollviews
 	draw their frame only around contents (like Motif), or around
 	contents, scrollbars and corner widgets (like Windows).
@@ -1605,6 +1704,12 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
     \value SH_TabBar_SelectMouseType which type of mouse event should
 	cause a tab to be selected.
 
+    \value SH_ListViewExpand_SelectMouseType which type of mouse event should
+	cause a listview expansion to be selected.
+
+    \value SH_TabBar_PreferNoArrows whether a tabbar should suggest a size
+        to prevent scoll arrows.
+
     \value SH_ComboBox_Popup allows popups as a combobox dropdown
 	menu.
 
@@ -1622,13 +1727,25 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
     \value SH_RichText_FullWidthSelection whether richtext selections
 	should extend the full width of the document.
 
-    \value SH_PopupMenu_Scrollable whether popupmenu's must support
-	scrolling.
+    \value SH_GroupBox_TextLabelVerticalAlignment how to vertically align a
+        groupbox's text label.
+
+    \value SH_GroupBox_TextLabelColor how to paint a groupbox's text label.
+
+    \value SH_DialogButtons_DefaultButton which buttons gets the
+        default status in a dialog's button widget.
 
     \value SH_CustomBase  base value for custom ControlElements. All
 	values above this are reserved for custom use. Therefore,
 	custom values must be greater than this value.
 
+    \value SH_ToolBox_SelectedPageTitleBold Boldness of the selected
+    page title in a QToolBox.
+
+    \value SH_LineEdit_PasswordCharacter The QChar Unicode character
+    to be used for passwords.
+
+    \value SH_Table_GridLineColor
 
     \sa styleHint()
 */
@@ -1660,6 +1777,7 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
     \value SP_MessageBoxInformation the 'information' icon.
     \value SP_MessageBoxWarning the 'warning' icon.
     \value SP_MessageBoxCritical the 'critical' icon.
+    \value SP_MessageBoxQuestion the 'question' icon.
 
 
     \value SP_DockWindowCloseButton  close button on dock windows;
@@ -1670,7 +1788,6 @@ void QStyle::drawItem( QPainter *p, const QRect &r,
 	values above this are reserved for custom use. Therefore,
 	custom values must be greater than this value.
 
-
     \sa stylePixmap()
 */
 
