@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id$
+** $Id: qt/qsocketdevice_unix.cpp   3.2.1   edited Jun 19 13:15 $
 **
 ** Implementation of QSocketDevice class.
 **
 ** Created : 970521
 **
-** Copyright (C) 1992-2001 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2002 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the network module of the Qt GUI Toolkit.
 **
@@ -35,11 +35,6 @@
 **
 **********************************************************************/
 
-#include "qsocketdevice.h"
-
-#ifndef QT_NO_NETWORK
-
-#include "qwindowdefs.h"
 #include "qplatformdefs.h"
 
 // Almost always the same. If not, specify in qplatformdefs.h.
@@ -47,43 +42,46 @@
 # define QT_SOCKOPTLEN_T QT_SOCKLEN_T
 #endif
 
-// Tru64 redefines accept() to _accept() when _XOPEN_SOURCE_EXTENDED is
-// defined.  This breaks our sources.
+// Tru64 redefines accept -> _accept with _XOPEN_SOURCE_EXTENDED
 static inline int qt_socket_accept(int s, struct sockaddr *addr, QT_SOCKLEN_T *addrlen)
 { return ::accept(s, addr, addrlen); }
 #if defined(accept)
 # undef accept
 #endif
 
-// Solaris redefines bind to __xnet_bind when _XOPEN_SOURCE_EXTENDED is
-// defined.  This breaks our sources.
+// Solaris redefines bind -> __xnet_bind with _XOPEN_SOURCE_EXTENDED
 static inline int qt_socket_bind(int s, struct sockaddr *addr, QT_SOCKLEN_T addrlen)
 { return ::bind(s, addr, addrlen); }
 #if defined(bind)
 # undef bind
 #endif
 
-// Solaris redefines connect to __xnet_connect when _XOPEN_SOURCE_EXTENDED is
-// defined.  This breaks our sources.
+// Solaris redefines connect -> __xnet_connect with _XOPEN_SOURCE_EXTENDED
 static inline int qt_socket_connect(int s, struct sockaddr *addr, QT_SOCKLEN_T addrlen)
 { return ::connect(s, addr, addrlen); }
 #if defined(connect)
 # undef connect
 #endif
 
-// UnixWare 7 redefines socket() to _socket().  This breaks our sources.
+// UnixWare 7 redefines listen -> _listen
+static inline int qt_socket_listen(int s, int backlog)
+{ return ::listen(s, backlog); }
+#if defined(listen)
+# undef listen
+#endif
+
+// UnixWare 7 redefines socket -> _socket
 static inline int qt_socket_socket(int domain, int type, int protocol)
 { return ::socket(domain, type, protocol); }
 #if defined(socket)
 # undef socket
 #endif
 
-// UnixWare 7 redefines listen() to _listen().  This breaks our sources.
-static inline int qt_socket_listen(int s, int backlog)
-{ return ::listen(s, backlog); }
-#if defined(listen)
-# undef listen
-#endif
+#include "qsocketdevice.h"
+
+#ifndef QT_NO_NETWORK
+
+#include "qwindowdefs.h"
 
 #include <errno.h>
 
@@ -96,10 +94,10 @@ void QSocketDevice::init()
 }
 
 /*!
-  Creates a new socket identifier. Returns -1 if there is a failure to
-  create the new identifier, error() explains why.
+    Creates a new socket identifier. Returns -1 if there is a failure
+    to create the new identifier; error() explains why.
 
-  \sa setSocket()
+    \sa setSocket()
 */
 
 int QSocketDevice::createNewSocket ()
@@ -108,7 +106,7 @@ int QSocketDevice::createNewSocket ()
     if ( s < 0 ) {
 	switch( errno ) {
 	case EPROTONOSUPPORT:
-	    e = Bug; // 0 is supposed to work for both types
+	    e = InternalError; // 0 is supposed to work for both types
 	    break;
 	case ENFILE:
 	    e = NoFiles; // special case for this
@@ -133,24 +131,26 @@ int QSocketDevice::createNewSocket ()
     return -1;
 }
 
-/*! \reimp
+/*!
+    \reimp
 
-  Closes the socket and sets the socket identifier to -1 (invalid).
+    Closes the socket and sets the socket identifier to -1 (invalid).
 
-  (This function ignores errors; if there are any then a file
-  descriptor leakage might result.  As far as we know, the only error
-  that can arise is EBADF, and that would of course not cause leakage.
-  There may be OS-specfic errors that we haven't come across,
-  however.)
+    (This function ignores errors; if there are any then a file
+    descriptor leakage might result. As far as we know, the only error
+    that can arise is EBADF, and that would of course not cause
+    leakage. There may be OS-specfic errors that we haven't come
+    across, however.)
 
-  \sa open()
+    \sa open()
 */
 void QSocketDevice::close()
 {
     if ( fd == -1 || !isOpen() )		// already closed
 	return;
     setFlags( IO_Sequential );
-    setStatus( IO_Ok );
+    resetStatus();
+    setState( 0 );
     ::close( fd );
 #if defined(QSOCKETDEVICE_DEBUG)
     qDebug( "QSocketDevice::close: Closed socket %x", fd );
@@ -161,15 +161,15 @@ void QSocketDevice::close()
 
 
 /*!
-  Returns TRUE if the socket is in blocking mode, or FALSE if it
-  is in nonblocking mode or if the socket is invalid.
+    Returns TRUE if the socket is valid and in blocking mode;
+    otherwise returns FALSE.
 
-  Note that this function does not set error().
+    Note that this function does not set error().
 
-  \warning On Windows, this function always returns TRUE since the
-  ioctlsocket() function is broken.
+    \warning On Windows, this function always returns TRUE since the
+    ioctlsocket() function is broken.
 
-  \sa setBlocking(), isValid()
+    \sa setBlocking(), isValid()
 */
 bool QSocketDevice::blocking() const
 {
@@ -181,18 +181,18 @@ bool QSocketDevice::blocking() const
 
 
 /*!
-  Makes the socket blocking if \a enable is TRUE or nonblocking if
-  \a enable is FALSE.
+    Makes the socket blocking if \a enable is TRUE or nonblocking if
+    \a enable is FALSE.
 
-  Sockets are blocking by default, but we recommend using
-  nonblocking socket operations, especially for GUI programs that need
-  to be responsive.
+    Sockets are blocking by default, but we recommend using
+    nonblocking socket operations, especially for GUI programs that
+    need to be responsive.
 
-  \warning On Windows, this function should be used with care since whenever
-  you use a QSocketNotifier on Windows, the socket is immediately made
-  nonblocking.
+    \warning On Windows, this function should be used with care since
+    whenever you use a QSocketNotifier on Windows, the socket is
+    immediately made nonblocking.
 
-  \sa blocking(), isValid()
+    \sa blocking(), isValid()
 */
 void QSocketDevice::setBlocking( bool enable )
 {
@@ -231,7 +231,7 @@ void QSocketDevice::setBlocking( bool enable )
 
 
 /*!
-  Returns the value of the socket option \a opt.
+    Returns the value of the socket option \a opt.
 */
 int QSocketDevice::option( Option opt ) const
 {
@@ -267,7 +267,7 @@ int QSocketDevice::option( Option opt ) const
 		that->e = Impossible;
 		break;
 	    case EFAULT:
-		that->e = Bug;
+		that->e = InternalError;
 		break;
 	    default:
 		that->e = UnknownError;
@@ -281,7 +281,7 @@ int QSocketDevice::option( Option opt ) const
 
 
 /*!
-  Sets the socket option \a opt to \a v.
+    Sets the socket option \a opt to \a v.
 */
 void QSocketDevice::setOption( Option opt, int v )
 {
@@ -312,7 +312,7 @@ void QSocketDevice::setOption( Option opt, int v )
 	    e = Impossible;
 	    break;
 	case EFAULT:
-	    e = Bug;
+	    e = InternalError;
 	    break;
 	default:
 	    e = UnknownError;
@@ -323,13 +323,13 @@ void QSocketDevice::setOption( Option opt, int v )
 
 
 /*!
-  Connects to the IP address and port specified by \a addr and \a port.
-  Returns TRUE if it establishes a connection, and FALSE if not.  error()
-  explains why.
+    Connects to the IP address and port specified by \a addr and \a
+    port. Returns TRUE if it establishes a connection; otherwise returns FALSE.
+    If it returns FALSE, error() explains why.
 
-  Note that error() commonly returns NoError for non-blocking sockets;
-  this just means that you can call connect() again in a little while
-  and it'll probably succeed.
+    Note that error() commonly returns NoError for non-blocking
+    sockets; this just means that you can call connect() again in a
+    little while and it'll probably succeed.
 */
 bool QSocketDevice::connect( const QHostAddress &addr, Q_UINT16 port )
 {
@@ -354,8 +354,10 @@ bool QSocketDevice::connect( const QHostAddress &addr, Q_UINT16 port )
 	fetchConnectionParameters();
 	return TRUE;
     }
-    if ( errno == EISCONN || errno == EALREADY || errno == EINPROGRESS )
+    if ( errno == EISCONN || errno == EALREADY || errno == EINPROGRESS ) {
+	fetchConnectionParameters();
 	return TRUE;
+    }
     if ( e != NoError || errno == EAGAIN || errno == EWOULDBLOCK ) {
 	return FALSE;
     }
@@ -366,7 +368,7 @@ bool QSocketDevice::connect( const QHostAddress &addr, Q_UINT16 port )
 	break;
     case EFAULT:
     case EAFNOSUPPORT:
-	e = Bug;
+	e = InternalError;
 	break;
     case ECONNREFUSED:
 	e = ConnectionRefused;
@@ -391,13 +393,13 @@ bool QSocketDevice::connect( const QHostAddress &addr, Q_UINT16 port )
 
 
 /*!
-  Assigns a name to an unnamed socket. The name is the host address \a address
-  and the port number \a port. If the operation succeeds, bind() returns TRUE.
-  Otherwise, it returns FALSE without changing what port() and address()
-  return.
+    Assigns a name to an unnamed socket. The name is the host address
+    \a address and the port number \a port. If the operation succeeds,
+    bind() returns TRUE; otherwise it returns FALSE without changing
+    what port() and address() return.
 
-  bind() is used by servers for setting up incoming connections.
-  Call bind() before listen().
+    bind() is used by servers for setting up incoming connections.
+    Call bind() before listen().
 */
 bool QSocketDevice::bind( const QHostAddress &address, Q_UINT16 port )
 {
@@ -429,7 +431,7 @@ bool QSocketDevice::bind( const QHostAddress &address, Q_UINT16 port )
 	    break;
 	case EFAULT: // a was illegal
 	case ENAMETOOLONG: // sz was wrong
-	    e = Bug;
+	    e = InternalError;
 	    break;
 	case EBADF: // AF_UNIX only
 	case ENOTSOCK: // AF_UNIX only
@@ -451,15 +453,15 @@ bool QSocketDevice::bind( const QHostAddress &address, Q_UINT16 port )
 
 
 /*!
-  Specifies how many pending connections a server socket can have.
-  Returns TRUE if the operation was successful, otherwise FALSE.
+    Specifies how many pending connections a server socket can have.
+    Returns TRUE if the operation was successful; otherwise returns
+    FALSE. A \a backlog value of 50 is quite common.
 
-  The listen() call only applies to sockets where type() is \c Stream,
-  not \c Datagram sockets.  listen() must not be called before bind()
-  or after accept().  It is common to use a \a backlog value of 50 on
-  most Unix systems.
+    The listen() call only applies to sockets where type() is \c
+    Stream, i.e. not to \c Datagram sockets. listen() must not be
+    called before bind() or after accept().
 
-  \sa bind(), accept()
+    \sa bind(), accept()
 */
 bool QSocketDevice::listen( int backlog )
 {
@@ -474,11 +476,11 @@ bool QSocketDevice::listen( int backlog )
 
 
 /*!
-  Extracts the first connection from the queue of pending connections
-  for this socket and returns a new socket identifier.  Returns -1
-  if the operation failed.
+    Extracts the first connection from the queue of pending
+    connections for this socket and returns a new socket identifier.
+    Returns -1 if the operation failed.
 
-  \sa bind(), listen()
+    \sa bind(), listen()
 */
 int QSocketDevice::accept()
 {
@@ -521,7 +523,7 @@ int QSocketDevice::accept()
 	    e = Impossible;
 	    break;
 	case EFAULT:
-	    e = Bug;
+	    e = InternalError;
 	    break;
 	case ENOMEM:
 	case ENOBUFS:
@@ -537,44 +539,61 @@ int QSocketDevice::accept()
 
 
 /*!
-  Returns the number of bytes available for reading, or -1 if an
-  error occurred.
+    Returns the number of bytes available for reading, or -1 if an
+    error occurred.
 
-  \warning On Microsoft Windows, we use the ioctlsocket() function
-  to determine the number of bytes queued on the socket.
-  According to Microsoft (KB Q125486), ioctlsocket() sometimes
-  return an incorrect number.  The only safe way to determine the
-  amount of data on the socket is to read it using readBlock().
-  QSocket has workarounds to deal with this problem.
+    \warning On Microsoft Windows, we use the ioctlsocket() function
+    to determine the number of bytes queued on the socket. According
+    to Microsoft (KB Q125486), ioctlsocket() sometimes returns an
+    incorrect number. The only safe way to determine the amount of
+    data on the socket is to read it using readBlock(). QSocket has
+    workarounds to deal with this problem.
 */
 Q_LONG QSocketDevice::bytesAvailable() const
 {
     if ( !isValid() )
 	return -1;
+
+    /*
+      Apparently, there is not consistency among different operating
+      systems on how to use FIONREAD.
+
+      FreeBSD, Linux and Solaris all expect the 3rd argument to
+      ioctl() to be an int, which is normally 32-bit even on 64-bit
+      machines.
+
+      IRIX, on the other hand, expects a size_t, which is 64-bit on
+      64-bit machines.
+
+      So, the solution is to use size_t initialized to zero to make
+      sure all bits are set to zero, preventing underflow with the
+      FreeBSD/Linux/Solaris ioctls.
+    */
+    size_t nbytes = 0;
     // gives shorter than true amounts on Unix domain sockets.
-    int nbytes = 0;
     if ( ::ioctl(fd, FIONREAD, (char*)&nbytes) < 0 )
 	return -1;
-    return nbytes;
+    return (Q_LONG) *((int *) &nbytes);
 }
 
 
 /*!
-  Wait up to \a msecs milliseconds for more data to be available.
-  If \a msecs is -1 the call will block indefinitely.
+    Wait up to \a msecs milliseconds for more data to be available. If
+    \a msecs is -1 the call will block indefinitely.
 
-  This is a blocking call and should be avoided in event driven
-  applications.
+    Returns the number of bytes available for reading, or -1 if an
+    error occurred.
 
-  Returns the number of bytes available for reading, or -1 if an
-  error occurred.
+    If \a timeout is non-null and no error occurred (i.e. it does not
+    return -1): this function sets \a *timeout to TRUE, if the reason
+    for returning was that the timeout was reached; otherwise it sets
+    \a *timeout to FALSE. This is useful to find out if the peer
+    closed the connection.
 
-  If \a timeout is non-null and no error occurred (i.e. it does not return -1),
-  then this function sets \a timeout out to TRUE, if the reason for returning
-  was that the timeout was reached, otherwise it sets \a timeout to FALSE. This
-  is useful to find out if the peer closed the connection.
+    \warning This is a blocking call and should be avoided in event
+    driven applications.
 
-  \sa bytesAvailable()
+    \sa bytesAvailable()
 */
 Q_LONG QSocketDevice::waitForMore( int msecs, bool *timeout ) const
 {
@@ -607,8 +626,8 @@ Q_LONG QSocketDevice::waitForMore( int msecs, bool *timeout ) const
 
 
 /*!
-  Reads max \a maxlen bytes from the socket into \a data and returns
-  the number of bytes read.  Returns -1 if an error occurred.
+    Reads \a maxlen bytes from the socket into \a data and returns the
+    number of bytes read. Returns -1 if an error occurred.
 */
 Q_LONG QSocketDevice::readBlock( char *data, Q_ULONG maxlen )
 {
@@ -674,6 +693,7 @@ Q_LONG QSocketDevice::readBlock( char *data, Q_ULONG maxlen )
 	    case EPIPE:
 	    case ECONNRESET:
 		// connection closed
+		close();
 		r = 0;
 		break;
 	    default:
@@ -687,10 +707,10 @@ Q_LONG QSocketDevice::readBlock( char *data, Q_ULONG maxlen )
 
 
 /*!
-  Writes \a len bytes to the socket from \a data and returns
-  the number of bytes written.  Returns -1 if an error occurred.
+    Writes \a len bytes to the socket from \a data and returns the
+    number of bytes written. Returns -1 if an error occurred.
 
-  This is used for \c QSocketDevice::Stream sockets.
+    This is used for \c QSocketDevice::Stream sockets.
 */
 Q_LONG QSocketDevice::writeBlock( const char *data, Q_ULONG len )
 {
@@ -720,6 +740,7 @@ Q_LONG QSocketDevice::writeBlock( const char *data, Q_ULONG len )
     }
     bool done = FALSE;
     int r = 0;
+    bool timeout;
     while ( !done ) {
 	r = ::write( fd, data, len );
 	done = TRUE;
@@ -729,8 +750,12 @@ Q_LONG QSocketDevice::writeBlock( const char *data, Q_ULONG len )
 	    case EINTR: // signal - call read() or whatever again
 		done = FALSE;
 		break;
-	    case ENOSPC:
 	    case EPIPE:
+		// connection closed
+		close();
+		r = 0;
+		break;
+	    case ENOSPC:
 	    case EIO:
 	    case EISDIR:
 	    case EBADF:
@@ -753,18 +778,25 @@ Q_LONG QSocketDevice::writeBlock( const char *data, Q_ULONG len )
 		e = UnknownError;
 		break;
 	    }
+	} else if ( waitForMore( 0, &timeout ) == 0 ) {
+	    if ( !timeout ) {
+		// connection closed
+		close();
+	    }
 	}
     }
     return r;
 }
 
 
-/*!  \overload
-  Writes \a len bytes to the socket from \a data and returns
-  the number of bytes written.  Returns -1 if an error occurred.
+/*!
+    \overload
 
-  This is used for \c QSocketDevice::Datagram sockets. You have to specify the
-  \a host and \a port of the destination of the data.
+    Writes \a len bytes to the socket from \a data and returns the
+    number of bytes written. Returns -1 if an error occurred.
+
+    This is used for \c QSocketDevice::Datagram sockets. You must
+    specify the \a host and \a port of the destination of the data.
 */
 Q_LONG QSocketDevice::writeBlock( const char * data, Q_ULONG len,
 			       const QHostAddress & host, Q_UINT16 port )
@@ -856,8 +888,8 @@ Q_LONG QSocketDevice::writeBlock( const char * data, Q_ULONG len,
 
 
 /*!
-  Fetches information about both ends of the connection - whatever
-  is available.
+    Fetches information about both ends of the connection: whatever is
+    available.
 */
 void QSocketDevice::fetchConnectionParameters()
 {
@@ -876,6 +908,7 @@ void QSocketDevice::fetchConnectionParameters()
 	p = ntohs( sa.sin_port );
 	a = QHostAddress( ntohl( sa.sin_addr.s_addr ) );
     }
+    sz = sizeof( sa );
     if ( !::getpeername( fd, (struct sockaddr *)(&sa), &sz ) ) {
 	pp = ntohs( sa.sin_port );
 	pa = QHostAddress( ntohl( sa.sin_addr.s_addr ) );
@@ -884,12 +917,12 @@ void QSocketDevice::fetchConnectionParameters()
 
 
 /*!
-  Returns the port number of the port this socket device is connected to. This
-  may be 0 for a while, but is set to something sensible when there is a
-  sensible value it can have.
+    Returns the port number of the port this socket device is
+    connected to. This may be 0 for a while, but is set to something
+    sensible as soon as a sensible value is available.
 
-  Note that for Datagram sockets, this is the source port of the last packet
-  received.
+    Note that for Datagram sockets, this is the source port of the
+    last packet received, and that it is in native byte order.
 */
 Q_UINT16 QSocketDevice::peerPort() const
 {
@@ -898,12 +931,12 @@ Q_UINT16 QSocketDevice::peerPort() const
 
 
 /*!
-  Returns the address of the port this socket device is connected to. This may
-  be 0.0.0.0 for a while, but is set to something sensible when there is a
-  sensible value it can have.
+    Returns the address of the port this socket device is connected
+    to. This may be 0.0.0.0 for a while, but is set to something
+    sensible as soon as a sensible value is available.
 
-  Note that for Datagram sockets, this is the source port of the last
-  packet received, and that it is in native byte order.
+    Note that for Datagram sockets, this is the source port of the
+    last packet received.
 */
 QHostAddress QSocketDevice::peerAddress() const
 {
