@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id:  qt/qplatinumstyle.cpp   3.0.2   edited Oct 12 12:18 $
+** $Id: qt/qplatinumstyle.cpp   3.2.1   edited May 27 08:45 $
 **
 ** Implementation of Platinum-like style class
 **
 ** Created : 981231
 **
-** Copyright (C) 1998-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1998-2002 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the widgets module of the Qt GUI Toolkit.
 **
@@ -37,7 +37,7 @@
 
 #include "qplatinumstyle.h"
 
-#ifndef QT_NO_STYLE_PLATINUM
+#if !defined(QT_NO_STYLE_PLATINUM) || defined(QT_PLUGIN)
 
 #include "qapplication.h"
 #include "qcombobox.h"
@@ -50,16 +50,18 @@
 #include "qslider.h"
 #include <limits.h>
 
-// NOT REVISED
 /*!
-  \class QPlatinumStyle qplatinumstyle.h
-  \brief The QPlatinumStyle class provides Mac/Platinum look and feel.
-  \ingroup appearance
+    \class QPlatinumStyle qplatinumstyle.h
+    \brief The QPlatinumStyle class provides Mac/Platinum look and feel.
 
-  This class implements the Platinum look and feel. It's an
-  experimental class that tries to resemble a Macinosh-like GUI style
-  with the QStyle system. The emulation is, however, far from being
-  perfect yet.
+    \ingroup appearance
+
+    This class implements the Platinum look and feel. It's an
+    experimental class that tries to resemble a Macinosh-like GUI
+    style with the QStyle system. The emulation is currently far from
+    perfect.
+
+    \sa QAquaStyle
 */
 
 
@@ -752,6 +754,8 @@ void QPlatinumStyle::drawControl( ControlElement element,
 	    SFlags flags;
 	    flags = Style_Default;
 	    btn = (const QPushButton*)widget;
+	    p->setBrushOrigin( -widget->backgroundOffset().x(),
+			       -widget->backgroundOffset().y() );
 
 	    // take care of the flags based on what we know...
 	    if ( btn->isDown() )
@@ -884,7 +888,7 @@ void QPlatinumStyle::drawControl( ControlElement element,
 			       g, flags, opt );
 		w -= dx;
 	    }
-
+#ifndef QT_NO_ICONSET
 	    if ( btn->iconSet() && !btn->iconSet()->isNull() ) {
 		QIconSet::Mode mode = btn->isEnabled()
 				      ? QIconSet::Normal : QIconSet::Disabled;
@@ -901,7 +905,7 @@ void QPlatinumStyle::drawControl( ControlElement element,
 		x += pixw + 4;
 		w -= pixw + 4;
 	    }
-
+#endif
 	    drawItem( p, QRect( x, y, w, h ),
 		      AlignCenter | ShowPrefix,
 		      btn->colorGroup(), btn->isEnabled(),
@@ -1201,7 +1205,7 @@ void QPlatinumStyle::drawComplexControl( ComplexControl control,
 		p->drawPoint( x + w - 3, y + h - 3 );
 		// ### end slider groove
 
-		if ( slider->hasFocus() )
+		if ( how & Style_HasFocus )
 		    drawPrimitive( PE_FocusRect, p, groove, cg );
 	    }
 
@@ -1318,149 +1322,113 @@ QRect QPlatinumStyle::querySubControlMetrics( ComplexControl control,
 					      SubControl sc,
 					      const QStyleOption& opt ) const
 {
-    QRect rect;
     switch( control ) {
-    case CC_ComboBox:
 #ifndef QT_NO_COMBOBOX
+    case CC_ComboBox:
 	const QComboBox *cb;
 	cb = (const QComboBox *)widget;
 	switch( sc ) {
-	case SC_ComboBoxArrow:
-	    {
-		rect = cb->rect();
-		int xx,
-		    yy,
-		    ww,
-		    hh;
-
-		if( QApplication::reverseLayout() )
-		    xx = rect.x();
-		else
-		    xx = rect.x() + rect.width() - 20;
-		yy = rect.y();
-		ww = 20;
-		hh = rect.height();
-		rect.setRect( xx, yy, ww, hh );
-		break;
-	    }
+	case SC_ComboBoxArrow: {
+	    QRect ir = cb->rect();
+	    int xx;
+	    if( QApplication::reverseLayout() )
+		xx = ir.x();
+	    else
+		xx = ir.x() + ir.width() - 20;
+	    return QRect( xx, ir.y(), 20, ir.height()); }
 	default:
-	    rect = QWindowsStyle::querySubControlMetrics( control, widget, sc,
-							  opt );
 	    break;
 	}
-#endif
 	break;
-    case CC_ScrollBar:
-	{
+#endif
 #ifndef QT_NO_SCROLLBAR
-	    const QScrollBar *sb;
-	    sb = (const QScrollBar *)widget;
-	    int sliderStart = sb->sliderStart();
-	    int sbextent = pixelMetric( PM_ScrollBarExtent, widget );
-	    int maxlen = ((sb->orientation() == Qt::Horizontal) ?
-			  sb->width() : sb->height()) - ( sbextent * 2 );
+    case CC_ScrollBar: {
+	const QScrollBar *sb;
+	sb = (const QScrollBar *)widget;
+	int sliderStart = sb->sliderStart();
+	int sbextent = pixelMetric( PM_ScrollBarExtent, widget );
+	int maxlen = ((sb->orientation() == Qt::Horizontal) ?
+		      sb->width() : sb->height()) - ( sbextent * 2 );
 
-	    int sliderlen;
+	int sliderlen;
 
-	    // calculate length
-	    if ( sb->maxValue() != sb->minValue() ) {
-		uint range = sb->maxValue() - sb->minValue();
-		sliderlen = ( sb->pageStep() * maxlen ) /
-			    ( range + sb->pageStep() );
+	// calculate length
+	if ( sb->maxValue() != sb->minValue() ) {
+	    uint range = sb->maxValue() - sb->minValue();
+	    sliderlen = ( sb->pageStep() * maxlen ) /
+			( range + sb->pageStep() );
 
-		int slidermin = pixelMetric( PM_ScrollBarSliderMin, widget );
-		if ( sliderlen < slidermin || range > INT_MAX / 2 )
-		    sliderlen = slidermin;
-		if ( sliderlen > maxlen )
-		    sliderlen = maxlen;
-	    } else
+	    int slidermin = pixelMetric( PM_ScrollBarSliderMin, widget );
+	    if ( sliderlen < slidermin || range > INT_MAX / 2 )
+		sliderlen = slidermin;
+	    if ( sliderlen > maxlen )
 		sliderlen = maxlen;
+	} else {
+	    sliderlen = maxlen;
+	}
 
-
-	    switch ( sc ) {
-	    case SC_ScrollBarSubLine:
-		if ( sb->orientation() == Qt::Horizontal )
-		    rect.setRect( sb->width() - 2 * sbextent, 0,
-				  sbextent, sbextent );
-		else
-		    rect.setRect( 0, sb->height() - 2 * sbextent,
-				  sbextent, sbextent );
-		break;
-	    case SC_ScrollBarAddLine:
-		if ( sb->orientation() == Qt::Horizontal )
-		    rect.setRect( sb->width() - sbextent, 0, sbextent,
-				  sbextent);
-		else
-		    rect.setRect(0, sb->height() - sbextent, sbextent,
-				 sbextent);
-		break;
-	    case SC_ScrollBarSubPage:
-		if ( sb->orientation() == Qt::Horizontal )
-		    rect.setRect( 1, 0, sliderStart, sbextent );
-		else
-		    rect.setRect( 0, 1, sbextent, sliderStart );
-		break;
-	    case SC_ScrollBarAddPage:
-		if ( sb->orientation() == Qt::Horizontal )
-		    rect.setRect( sliderStart + sliderlen, 0,
-				  maxlen - sliderStart
-				  - sliderlen, sbextent );
-		else
-		    rect.setRect( 0, sliderStart + sliderlen,
-				  sbextent, maxlen - sliderStart - sliderlen );
-		break;
-	    case SC_ScrollBarGroove:
-		if ( sb->orientation() == Qt::Horizontal )
-		    rect.setRect( 1, 0, sb->width() - sbextent * 2,
-				  sb->height() );
-		else
-		    rect.setRect( 0, 1, sb->width(),
-				  sb->height() - sbextent * 2 );
-		break;
-	    default:
-		rect = QWindowsStyle::querySubControlMetrics( control, widget,
-							      sc, opt );
-		break;
+	switch ( sc ) {
+	case SC_ScrollBarSubLine:
+	    if ( sb->orientation() == Qt::Horizontal ) {
+		int buttonw = QMIN( sb->width() / 2, sbextent );
+		return QRect( sb->width() - 2 * buttonw, 0, buttonw, sbextent );
+	    } else {
+		int buttonh = QMIN( sb->height() / 2, sbextent );
+		return QRect( 0, sb->height() - 2 * buttonh, sbextent, buttonh );
 	    }
-#endif
+	case SC_ScrollBarAddLine:
+	    if ( sb->orientation() == Qt::Horizontal ) {
+		int buttonw = QMIN( sb->width() / 2, sbextent );
+		return QRect( sb->width() - buttonw, 0, sbextent, buttonw );
+	    } else {
+		int buttonh = QMIN( sb->height() / 2, sbextent );
+		return QRect(0, sb->height() - buttonh, sbextent, buttonh );
+	    }
+	case SC_ScrollBarSubPage:
+	    if ( sb->orientation() == Qt::Horizontal )
+		return QRect( 1, 0, sliderStart, sbextent );
+	    return QRect( 0, 1, sbextent, sliderStart );
+	case SC_ScrollBarAddPage:
+	    if ( sb->orientation() == Qt::Horizontal )
+		return QRect( sliderStart + sliderlen, 0, maxlen - sliderStart - sliderlen, sbextent );
+	    return QRect( 0, sliderStart + sliderlen, sbextent, maxlen - sliderStart - sliderlen );
+	case SC_ScrollBarGroove:
+	    if ( sb->orientation() == Qt::Horizontal )
+		return QRect( 1, 0, sb->width() - sbextent * 2, sb->height() );
+	    return QRect( 0, 1, sb->width(), sb->height() - sbextent * 2 );
+	default:
 	    break;
 	}
-    case CC_Slider:
-	{
+	break; }
+#endif
 #ifndef QT_NO_SLIDER
-	    const QSlider *slider = (const QSlider *) widget;
-	    int tickOffset = pixelMetric( PM_SliderTickmarkOffset, widget);
-	    int thickness = pixelMetric( PM_SliderControlThickness, widget);
-	    int mid = thickness / 2;
-	    int ticks = slider->tickmarks();
-	    int len = pixelMetric( PM_SliderLength, widget );
+    case CC_Slider: {
 
-	    switch ( sc ) {
-	    case SC_SliderGroove:
-		if ( ticks & QSlider::Above )
-		    mid += len / 8;
-		if ( ticks & QSlider::Below )
-		    mid -= len / 8;
-		if ( slider->orientation() == QSlider::Horizontal )
-		    rect.setRect( 0, tickOffset,
-				  slider->width(), thickness );
-		else
-		    rect.setRect( tickOffset, 0, thickness, slider->height() );
-		break;
-	    default:
-		rect = QWindowsStyle::querySubControlMetrics( control, widget,
-							      sc, opt );
-		break;
-	    }
-#endif
+	const QSlider *slider = (const QSlider *) widget;
+	int tickOffset = pixelMetric( PM_SliderTickmarkOffset, widget);
+	int thickness = pixelMetric( PM_SliderControlThickness, widget);
+	int mid = thickness / 2;
+	int ticks = slider->tickmarks();
+	int len = pixelMetric( PM_SliderLength, widget );
+
+	switch ( sc ) {
+	case SC_SliderGroove:
+	    if ( ticks & QSlider::Above )
+		mid += len / 8;
+	    if ( ticks & QSlider::Below )
+		mid -= len / 8;
+	    if ( slider->orientation() == QSlider::Horizontal )
+		return QRect( 0, tickOffset, slider->width(), thickness );
+	    return QRect( tickOffset, 0, thickness, slider->height() );
+	default:
 	    break;
 	}
+	break; }
+#endif
     default:
-	rect = QWindowsStyle::querySubControlMetrics( control, widget,
-						      sc, opt );
 	break;
     }
-    return rect;
+    return QWindowsStyle::querySubControlMetrics( control, widget, sc, opt );
 }
 
 
@@ -1491,6 +1459,9 @@ int QPlatinumStyle::pixelMetric( PixelMetric metric,
     case PM_SliderLength:
 	ret = 17;
 	break;
+    case PM_MaximumDragDistance:
+	ret = -1;
+	break;
     default:
 	ret = QWindowsStyle::pixelMetric( metric, widget );
 	break;
@@ -1519,8 +1490,8 @@ QRect QPlatinumStyle::subRect( SubRect r, const QWidget *widget ) const
 }
 
 /*!
-  Mixes two colors \a c1 and \a c2 to a new color.
-  */
+    Mixes two colors \a c1 and \a c2 to a new color.
+*/
 QColor QPlatinumStyle::mixedColor(const QColor &c1, const QColor &c2) const
 {
     int h1,s1,v1,h2,s2,v2;
@@ -1530,10 +1501,10 @@ QColor QPlatinumStyle::mixedColor(const QColor &c1, const QColor &c2) const
 }
 
 /*!
-  Draws the nifty Macintosh decoration used on sliders using painter \a p and
-  colorgroup \a g. \a x, \a y, \a w, \a h and \a horizontal specify the geometry
-  and orientation of the riffles.
-  */
+    Draws the nifty Macintosh decoration used on sliders using painter
+    \a p and colorgroup \a g. \a x, \a y, \a w, \a h and \a horizontal
+    specify the geometry and orientation of the riffles.
+*/
 void QPlatinumStyle::drawRiffles( QPainter* p,  int x, int y, int w, int h,
 				  const QColorGroup &g, bool horizontal ) const
 {
