@@ -1,9 +1,9 @@
 /****************************************************************************
-** $Id$
+** $Id: qt/qlibrary_unix.cpp   3.2.1   edited May 21 00:40 $
 **
 ** Implementation of QLibraryPrivate class
 **
-** Created : 2000-01-01
+** Created : 000101
 **
 ** Copyright (C) 2000-2002 Trolltech AS.  All rights reserved.
 **
@@ -19,8 +19,8 @@
 ** packaging of this file.
 **
 ** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
-** Agreement provided with the Software.
+** licenses for Unix/X11 or for Qt/Embedded may use this file in accordance
+** with the Qt Commercial License Agreement provided with the Software.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -35,8 +35,15 @@
 **
 **********************************************************************/
 
+#include "qplatformdefs.h"
 #include "private/qlibrary_p.h"
 
+#ifndef QT_NO_LIBRARY
+
+#if defined(QT_AOUT_UNDERSCORE)
+#include <string.h>
+#endif
+
 /*
   The platform dependent implementations of
   - loadLibrary
@@ -46,9 +53,24 @@
   It's not too hard to guess what the functions do.
 */
 
-#if defined(Q_OS_HPUX)
-// for HP-UX < 11.x and 32 bit
-#include <dl.h>
+#if defined(Q_OS_MAC)
+
+bool QLibraryPrivate::loadLibrary()
+{
+    return FALSE;
+}
+
+bool QLibraryPrivate::freeLibrary()
+{
+    return FALSE;
+}
+
+void* QLibraryPrivate::resolveSymbol( const char* )
+{
+    return 0;
+}
+
+#elif defined(QT_HPUX_LD) // for HP-UX < 11.x and 32 bit
 
 bool QLibraryPrivate::loadLibrary()
 {
@@ -60,7 +82,7 @@ bool QLibraryPrivate::loadLibrary()
     pHnd = (void*)shl_load( filename.latin1(), BIND_DEFERRED | BIND_NONFATAL | DYNAMIC_PATH, 0 );
 #if defined(QT_DEBUG) || defined(QT_DEBUG_COMPONENT)
     if ( !pHnd )
-	qWarning( "Failed to load library %s!", filename.latin1() );
+	qWarning( "%s: failed to load library!", filename.latin1() );
 #endif
     return pHnd != 0;
 }
@@ -72,7 +94,8 @@ bool QLibraryPrivate::freeLibrary()
 
     if ( shl_unload( (shl_t)pHnd ) ) {
 #if defined(QT_DEBUG) || defined(QT_DEBUG_COMPONENT)
-	qWarning( "Failed to unload library!" );
+	QString filename = library->library();
+	qWarning( "%s: Failed to unload library!", filename.latin1() );
 #endif
 	return FALSE;
     }
@@ -88,14 +111,14 @@ void* QLibraryPrivate::resolveSymbol( const char* symbol )
     void* address = 0;
     if ( shl_findsym( (shl_t*)&pHnd, symbol, TYPE_UNDEFINED, &address ) < 0 ) {
 #if defined(QT_DEBUG_COMPONENT)
-	qWarning( "Couldn't resolve symbol \"%s\"", symbol );
+	QString filename = library->library();
+	qWarning( "%s: couldn't resolve symbol \"%s\"", filename.latin1(), symbol );
 #endif
     }
     return address;
 }
 
-#else // Q_OS_HPUX
-// Something else, assuming POSIX
+#else // POSIX
 #include <dlfcn.h>
 
 bool QLibraryPrivate::loadLibrary()
@@ -105,7 +128,7 @@ bool QLibraryPrivate::loadLibrary()
 
     QString filename = library->library();
 
-    pHnd = dlopen( filename.latin1() , RTLD_LAZY );
+    pHnd = dlopen( filename.latin1(), RTLD_LAZY );
 #if defined(QT_DEBUG) || defined(QT_DEBUG_COMPONENT)
     if ( !pHnd )
 	qWarning( "%s", dlerror() );
@@ -153,3 +176,5 @@ void* QLibraryPrivate::resolveSymbol( const char* symbol )
 }
 
 #endif // POSIX
+
+#endif
